--- loncom/interface/lonmeta.pm 2013/05/03 14:00:58 1.250
+++ loncom/interface/lonmeta.pm 2014/02/11 18:52:20 1.252
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Metadata display handler
#
-# $Id: lonmeta.pm,v 1.250 2013/05/03 14:00:58 bisitz Exp $
+# $Id: lonmeta.pm,v 1.252 2014/02/11 18:52:20 bisitz Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -389,9 +389,9 @@ sub select_course {
&mt('You can choose to transfer data from the added fields to the "Notes" field if you are planning to change the course association.').'
'.
&Apache::loncommon::start_data_table().
&Apache::loncommon::start_data_table_header_row().
- '
Copy to notes? | '."\n".
- 'Field name | '."\n".
- 'Values | '."\n".
+ ''.&mt('Copy to notes?').' | '."\n".
+ ''.&mt('Field Name').' | '."\n".
+ ''.&mt('Values').' | '."\n".
&Apache::loncommon::end_data_table_header_row().
$transfernotes.
&Apache::loncommon::end_data_table().'
';
@@ -455,7 +455,7 @@ sub prettyprint {
}
# MIME
if ($type eq 'mime') {
- return ' '.
+ return ' '.
&Apache::loncommon::filedescription($value);
}
# Person
@@ -778,7 +778,7 @@ sub handler {
if ($env{'request.state'} eq 'construct') {
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
+ 'text' => 'Authoring Space',
'href' => &Apache::loncommon::authorspace($uri),
});
}
@@ -829,7 +829,7 @@ sub handler {
$r->print(&pageheader());
&present_editable_metadata($r,$uri,'groups');
} elsif ($uri=~m|^/priv|) {
- # Construction space
+ # Authoring space
&Apache::lonhtmlcommon::add_breadcrumb({
'text' => 'Edit Metadata',
'href' => '',
@@ -1292,7 +1292,7 @@ sub print_dynamic_metadata {
#####################################################
sub present_editable_metadata {
my ($r,$uri,$file_type) = @_;
# Construction Space Call
# Header
my $disuri=$uri;
my $fn=&Apache::lonnet::filelocation('',$uri);
@@ -1292,7 +1292,7 @@ sub print_dynamic_metadata {
sub present_editable_metadata {
my ($r,$uri,$file_type) = @_;
- # Construction Space Call
+ # Authoring Space Call
# Header
my $disuri=$uri;